// IIFE para evitar conflictos en el ámbito global
(function() {
    let diccionario = {};
    const mensajesContainer = document.getElementById('mensajes');
    const entradaMensaje = document.getElementById('texto-mensaje');
    let historialRespuestas = []; // Historial global de respuestas únicas

  async function cargarIntencionesDinamicamente() {
    try {
        const respuesta = await fetch('./');
        const html = await respuesta.text();
        const parser = new DOMParser();
        const doc = parser.parseFromString(html, 'text/html');

        const archivos = Array.from(doc.querySelectorAll('a'))
            .map(link => link.getAttribute('href'))
            .filter(file => file.endsWith('.json') && !file.startsWith('-'));

        for (const archivo of archivos) {
            const nombreContexto = archivo.replace('.json', '');
            const respuestaArchivo = await fetch(`./${archivo}`);
            const datos = await respuestaArchivo.json();
            diccionario[nombreContexto] = datos;
        }

        console.log("Intenciones cargadas:", Object.keys(diccionario));
    } catch (error) {
        console.error("Error cargando las intenciones dinámicas:", error);
        mostrarMensaje('bot', 'Lo siento, hubo un error al cargar la información. Por favor, inténtalo de nuevo más tarde.');
    }
}



    function limpiarTexto(texto) {
        texto = texto.toLowerCase();
        return texto.normalize('NFD')
        .replace(/[\u0300-\u036f]/g, '')
        .replace(/[¿?!¡]/g, '')
        .trim();
    }

    function encontrarPalabrasClave(texto) {
        texto = limpiarTexto(texto);
        const palabrasEncontradas = [];

        for (let categoria in diccionario) {
            const palabrasClave = diccionario[categoria].palabras;
            palabrasClave.forEach(palabra => {
                if (texto.includes(palabra)) {
                    palabrasEncontradas.push(categoria);
                }
            });
        }

        return [...new Set(palabrasEncontradas)]; // Eliminar duplicados
    }

  function obtenerRespuestaUnica(categoria) {
    const respuestasCategoria = diccionario[categoria].respuestas;

    // Respuesta condicional para la categoría "info"
    if (categoria === '00a.conocenos' || categoria === 'empresa') { // Ejemplo de respuesta automática por interceptación de categoría.
        return "![Logo de la Empresa](https://placehold.co/250x60/EEE/555?text=Logo%20XYZ&font=Montserrat)\n\n### Empresa XYZ\n\n**Misión**: Brindar soluciones tecnológicas innovadoras que impulsen el crecimiento y eficiencia de nuestros clientes.\n\n**Visión**: Ser el líder en la transformación digital para pequeñas y medianas empresas.\n\n### [Visita nuestro sitio web](https://ejemplo.com) para más detalles.";
    }

    // Respuesta condicional para la categoría "contacto"
    if (categoria === '00d.contacto') {
        return "Si necesitas ayuda, puedes enviarnos un correo a [soporte@ejemplo.com](mailto:soporte@ejemplo.com) o llamarnos al +1 (123) 456-7890.\n\nTambién estamos disponibles en WhatsApp para resolver cualquier consulta. \n\n### Haz clic [aquí para contactarnos por Whatsapp](https://wa.me/1234567890).";
    }

    // Filtrar respuestas no usadas
    const respuestasDisponibles = respuestasCategoria.filter(r => !historialRespuestas.includes(r));

    let respuesta;
    if (respuestasDisponibles.length > 0) {
        respuesta = respuestasDisponibles[Math.floor(Math.random() * respuestasDisponibles.length)];
    } else {
        // Si todas las respuestas se usaron, reinicia historial local de la categoría
        respuesta = respuestasCategoria[Math.floor(Math.random() * respuestasCategoria.length)];
    }

    // Registrar respuesta en el historial global
    historialRespuestas.push(respuesta);
    return respuesta;
}

    function enviarMensaje() {
        const mensaje = entradaMensaje.value;
        if (!mensaje) return;

        mostrarMensaje('usuario', mensaje);

        const palabrasClave = encontrarPalabrasClave(mensaje);

    const respuestasGeneradas = new Set(); // Evitar respuestas duplicadas para una consulta

    if (palabrasClave.length > 0) {
        palabrasClave.forEach(categoria => {
            const respuesta = obtenerRespuestaUnica(categoria);

            // Evitar enviar una respuesta que ya se usó en este turno
            if (!respuestasGeneradas.has(respuesta)) {
                respuestasGeneradas.add(respuesta);
                mostrarMensaje('bot', respuesta, true); // 'true' para indicar que es Markdown
            }
        });
    } else {
        mostrarMensaje('bot', '**Lo siento, no comprendo completamente tu mensaje.**\n\n¿Podrías probar con otros términos?');
    }

    entradaMensaje.value = '';
}


function mostrarMensaje(tipo, texto, esHTML = false) {
    const mensajeDiv = document.createElement('div');
    mensajeDiv.classList.add(tipo);

    // Siempre procesamos las respuestas como Markdown
    mensajeDiv.innerHTML = marked.parse(texto); // Procesamos siempre con marked.parse()

    // Resaltar las respuestas del bot
    if (tipo === 'bot') {
        mensajeDiv.classList.add('respuesta-bot');
    }

    mensajesContainer.appendChild(mensajeDiv);
    mensajesContainer.scrollTop = mensajesContainer.scrollHeight;
}



function obtenerParametrosURL() {
    const urlParams = new URLSearchParams(window.location.search);
    const pregunta = urlParams.get('pregunta');
    if (pregunta) {
        mostrarMensaje('usuario', pregunta);
        const palabrasClave = encontrarPalabrasClave(pregunta);
        const respuestasGeneradas = new Set();

        if (palabrasClave.length > 0) {
            palabrasClave.forEach(categoria => {
                const respuesta = obtenerRespuestaUnica(categoria);

                if (!respuestasGeneradas.has(respuesta)) {
                    respuestasGeneradas.add(respuesta);
                    mostrarMensaje('bot', respuesta, true);
                }
            });
        } else {
            mostrarMensaje('bot', 'Lo siento, no tengo información para esa consulta.');
        }
    }
}

entradaMensaje.addEventListener('keypress', (e) => {
    if (e.key === 'Enter') {
        enviarMensaje();
    }
});

window.onload = async () => {
    entradaMensaje.focus();
    mostrarMensaje('bot', '### 🤓 ¡Hola! Soy tu asistente virtual pseudo-inteligente \n\n\**Estoy aquí para ayudarte y brindar información pertinente.**');
    await cargarIntencionesDinamicamente();
    obtenerParametrosURL();
};
})();
